@@ -38,9 +38,7 @@
 #define FLAG_FORCE_SORT         0x00000800
 #define FLAG_CAPTION_RES        0x00001000
 /* Response-related flags */
-#define FLAG_HAS_CAPTIONS       0x20000000
-#define FLAG_FREE_OBJECT_ID     0x40000000
-#define FLAG_ROOT_CONTAINER     0x80000000
+#define FLAG_HAS_CAPTIONS       0x80000000
 
 enum match_types {
 	EMatchNone,
@@ -91,14 +89,15 @@ struct client_type_s {
 struct client_cache_s {
 	struct in_addr addr;
 	unsigned char mac[6];
-	enum client_types type;
+	struct client_type_s *type;
 	time_t age;
+	int connections;
 };
 
 extern struct client_type_s client_types[];
 extern struct client_cache_s clients[CLIENT_CACHE_SLOTS];
 
-int SearchClientCache(struct in_addr addr, int quiet);
-int AddClientCache(struct in_addr addr, int type);
+struct client_cache_s *SearchClientCache(struct in_addr addr, int quiet);
+struct client_cache_s *AddClientCache(struct in_addr addr, int type);
 
 #endif
