@@ -84,7 +84,6 @@ my_dst_mgr_init(j_compress_ptr cinfo)
 	dst->jdst.free_in_buffer = dst->sz;
 
 	return;
-
 }
 
 static boolean
@@ -100,7 +99,6 @@ my_dst_mgr_empty(j_compress_ptr cinfo)
 	dst->jdst.free_in_buffer = dst->sz - dst->used;
 
 	return TRUE;
-
 }
 
 static void
@@ -112,7 +110,6 @@ my_dst_mgr_term(j_compress_ptr cinfo)
 	dst->off = dst->buf + dst->used;
 
 	return;
-
 }
 
 static void
@@ -124,7 +121,6 @@ jpeg_memory_dest(j_compress_ptr cinfo, struct my_dst_mgr *dst)
 	cinfo->dest = (void *)dst;
 
 	return;
-
 }
 
 /* Source manager to read data from a buffer */
@@ -182,10 +178,8 @@ jpeg_memory_src(j_decompress_ptr cinfo, const unsigned char * buffer, size_t buf
 {
 	struct my_src_mgr *src;
 
-	if (! cinfo->src)
-	{
+	if (!cinfo->src)
 		cinfo->src = (*cinfo->mem->alloc_small)((void *)cinfo, JPOOL_PERMANENT, sizeof(struct my_src_mgr));;
-	}
 	src = (void *)cinfo->src;
 	src->pub.init_source = init_source;
 	src->pub.fill_input_buffer = fill_input_buffer;
@@ -424,7 +418,7 @@ image_new(int32_t width, int32_t height)
 }
 
 image_s *
-image_new_from_jpeg(const char * path, int is_file, const char * buf, int size, int scale, int rotate)
+image_new_from_jpeg(const char *path, int is_file, const uint8_t *buf, int size, int scale, int rotate)
 {
 	image_s *vimage;
 	FILE  *file = NULL;
@@ -447,7 +441,7 @@ image_new_from_jpeg(const char * path, int is_file, const char * buf, int size,
 	}
 	else
 	{
-		jpeg_memory_src(&cinfo, (const unsigned char *)buf, size);
+		jpeg_memory_src(&cinfo, buf, size);
 	}
 	if( setjmp(setjmp_buffer) )
 	{
@@ -488,6 +482,7 @@ image_new_from_jpeg(const char * path, int is_file, const char * buf, int size,
 	if(cinfo.rec_outbuf_height > 16)
 	{
 		DPRINTF(E_WARN, L_METADATA, "ERROR image_from_jpeg : (image_from_jpeg.c) JPEG uses line buffers > 16. Cannot load.\n");
+		jpeg_destroy_decompress(&cinfo);
 		image_free(vimage);
 		if( is_file )
 			fclose(file);
@@ -501,6 +496,7 @@ image_new_from_jpeg(const char * path, int is_file, const char * buf, int size,
 		if((ptr = malloc(w * 3 * cinfo.rec_outbuf_height + 16)) == NULL)
 		{
 			DPRINTF(E_WARN, L_METADATA, "malloc failed\n");
+			jpeg_destroy_decompress(&cinfo);
 			image_free(vimage);
 			if( is_file )
 				fclose(file);
@@ -815,6 +811,8 @@ image_save_to_jpeg_buf(image_s * pimage, int * size)
 	if((data = malloc(row_stride)) == NULL)
 	{
 		DPRINTF(E_WARN, L_METADATA, "malloc failed\n");
+		free(dst.buf);
+		jpeg_destroy_compress(&cinfo);
 		return NULL;
 	}
 	i = 0;
@@ -838,8 +836,8 @@ image_save_to_jpeg_buf(image_s * pimage, int * size)
 	return dst.buf;
 }
 
-int
-image_save_to_jpeg_file(image_s * pimage, const char * path)
+char *
+image_save_to_jpeg_file(image_s * pimage, char * path)
 {
 	int nwritten, size = 0;
 	unsigned char * buf;
@@ -847,16 +845,16 @@ image_save_to_jpeg_file(image_s * pimage, const char * path)
 
 	buf = image_save_to_jpeg_buf(pimage, &size);
 	if( !buf )
-		return -1;
+		return NULL;
  	dst_file = fopen(path, "w");
 	if( !dst_file )
 	{
 		free(buf);
-		return -1;
+		return NULL;
 	}
 	nwritten = fwrite(buf, 1, size, dst_file);
 	fclose(dst_file);
 	free(buf);
 
-	return (nwritten==size ? 0 : 1);
+	return (nwritten == size) ? path : NULL;
 }
