@@ -116,13 +116,13 @@ SendFormats(struct upnphttp *h, const char *sformat)
 }
 
 static char *
-unescape_tag(char *tag)
+tivo_unescape_tag(char *tag)
 {
-	modifyString(tag, "&amp;amp;", "&amp;");
-	modifyString(tag, "&amp;amp;lt;", "&lt;");
-	modifyString(tag, "&amp;lt;", "&lt;");
-	modifyString(tag, "&amp;amp;gt;", "&gt;");
-	modifyString(tag, "&amp;gt;", "&gt;");
+	modifyString(tag, "&amp;amp;", "&amp;", 1);
+	modifyString(tag, "&amp;amp;lt;", "&lt;", 1);
+	modifyString(tag, "&amp;lt;", "&lt;", 1);
+	modifyString(tag, "&amp;amp;gt;", "&gt;", 1);
+	modifyString(tag, "&amp;gt;", "&gt;", 1);
 	return tag;
 }
 
@@ -141,7 +141,7 @@ callback(void *args, int argc, char **argv, char **azColName)
 	if( strncmp(class, "item", 4) == 0 )
 	{
 		int flags = 0;
-		unescape_tag(title);
+		tivo_unescape_tag(title);
 		if( strncmp(mime, "audio", 5) == 0 )
 		{
 			flags |= FLAG_NO_PARAMS;
@@ -208,15 +208,15 @@ callback(void *args, int argc, char **argv, char **azColName)
 		{
 			return 0;
 		}
-		strcatf(str, "<Title>%s</Title>", unescape_tag(title));
+		strcatf(str, "<Title>%s</Title>", tivo_unescape_tag(title));
 		if( artist ) {
-			strcatf(str, "<ArtistName>%s</ArtistName>", unescape_tag(artist));
+			strcatf(str, "<ArtistName>%s</ArtistName>", tivo_unescape_tag(artist));
 		}
 		if( album ) {
-			strcatf(str, "<AlbumTitle>%s</AlbumTitle>", unescape_tag(album));
+			strcatf(str, "<AlbumTitle>%s</AlbumTitle>", tivo_unescape_tag(album));
 		}
 		if( genre ) {
-			strcatf(str, "<MusicGenre>%s</MusicGenre>", unescape_tag(genre));
+			strcatf(str, "<MusicGenre>%s</MusicGenre>", tivo_unescape_tag(genre));
 		}
 		if( resolution ) {
 			char *width = strsep(&resolution, "x");
@@ -277,7 +277,7 @@ callback(void *args, int argc, char **argv, char **azColName)
 		                 "<ContentType>x-tivo-container/folder</ContentType>"
 		               "</Content>"
 		             "</Links>",
-		             unescape_tag(title), count, id);
+		             tivo_unescape_tag(title), count, id);
 	}
 	strcatf(str, "</Item>");
 
@@ -308,7 +308,7 @@ SendItemDetails(struct upnphttp *h, int64_t item)
 	args.requested = 1;
 	xasprintf(&sql, SELECT_COLUMNS
 	               "from OBJECTS o left join DETAILS d on (d.ID = o.DETAIL_ID)"
-		       " where o.DETAIL_ID = %lld group by o.DETAIL_ID", item);
+		       " where o.DETAIL_ID = %lld group by o.DETAIL_ID", (long long)item);
 	DPRINTF(E_DEBUG, L_TIVO, "%s\n", sql);
 	ret = sqlite3_exec(db, sql, callback, (void *) &args, &zErrMsg);
 	free(sql);
